@@ -15,6 +15,7 @@
 #' (\bold{required}): input values containing at least De and De error. To plot
 #' more than one data set in one figure, a \code{list} of the individual data
 #' sets must be provided (e.g. \code{list(dataset.1, dataset.2)}).
+#'
 #' @param given.dose \code{\link{numeric}} (optional): given dose used for the
 #' dose recovery test to normalise data. If only one given dose is provided
 #' this given dose is valid for all input data sets (i.e., \code{values} is a
@@ -23,16 +24,21 @@
 #' plotted without normalisation (might be useful for preheat plateau tests).
 #' Note: Unit has to be the same as from the input values (e.g., Seconds or
 #' Gray).
+#'
 #' @param error.range \code{\link{numeric}}: symmetric error range in percent
 #' will be shown as dashed lines in the plot. Set \code{error.range} to 0 to
 #' void plotting of error ranges.
+#'
 #' @param preheat \code{\link{numeric}}: optional vector of preheat
 #' temperatures to be used for grouping the De values. If specified, the
 #' temperatures are assigned to the x-axis.
+#'
 #' @param boxplot \code{\link{logical}}: optionally plot values, that are
 #' grouped by preheat temperature as boxplots. Only possible when
 #' \code{preheat} vector is specified.
+#'
 #' @param mtext \code{\link{character}}: additional text below the plot title.
+#'
 #' @param summary \code{\link{character}} (optional): adds numerical output to
 #' the plot.  Can be one or more out of: \code{"n"} (number of samples),
 #' \code{"mean"} (mean De value), \code{"mean.weighted"} (error-weighted mean),
@@ -40,19 +46,23 @@
 #' deviation in percent), \code{"sdabs"} (absolute standard deviation),
 #' \code{"serel"} (relative standard error) and \code{"seabs"} (absolute
 #' standard error).
+#'
 #' @param summary.pos \code{\link{numeric}} or \code{\link{character}} (with
 #' default): optional position coordinates or keyword (e.g. \code{"topright"})
 #' for the statistical summary. Alternatively, the keyword \code{"sub"} may be
 #' specified to place the summary below the plot header. However, this latter
 #' option in only possible if \code{mtext} is not used.
+#'
 #' @param legend \code{\link{character}} vector (optional): legend content to
 #' be added to the plot.
+#'
 #' @param legend.pos \code{\link{numeric}} or \code{\link{character}} (with
 #' default): optional position coordinates or keyword (e.g. \code{"topright"})
 #' for the legend to be plotted.
 #' @param par.local \code{\link{logical}} (with default): use local graphical
 #' parameters for plotting, e.g. the plot is shown in one column and one row.
-#' If \code{par.local = FALSE}, global parameters are inherited.
+#' If \code{par.local = FALSE}, global parameters are inherited, i.e. parameters
+#' provided via \code{par()} work
 #' @param na.rm \code{\link{logical}}: indicating wether \code{NA} values are
 #' removed before plotting from the input data set
 #' @param \dots further arguments and graphical parameters passed to
@@ -61,7 +71,7 @@
 #'
 #' @note Further data and plot arguments can be added by using the appropiate R
 #' commands.
-#' @section Function version: 0.1.8
+#' @section Function version: 0.1.10
 #'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
 #' (France), Michael Dietze, GFZ Potsdam (Germany)
@@ -141,7 +151,7 @@
 #' @export
 plot_DRTResults <- function(
   values,
-  given.dose,
+  given.dose = NULL,
   error.range = 10,
   preheat,
   boxplot = FALSE,
@@ -233,7 +243,7 @@ plot_DRTResults <- function(
   }
 
   ylab <- if("ylab" %in% names(extraArgs)) {extraArgs$ylab} else
-  {if(!missing(given.dose)){
+  {if(!is.null(given.dose)){
     expression(paste("Normalised ", D[e], sep=""))
   }else{expression(paste(D[e], " [s]"), sep = "")}}
 
@@ -254,7 +264,7 @@ plot_DRTResults <- function(
   ## calculations and settings-------------------------------------------------
 
   ## normalise data if given.dose is given
-  if(!missing(given.dose)){
+  if(!is.null(given.dose)){
 
     if(length(given.dose) > 1){
 
@@ -318,7 +328,6 @@ plot_DRTResults <- function(
     } else {
       rep(seq(from = 1, to = length(values)), length(modes))
     }
-
   }
 
   ## calculate and paste statistical summary
@@ -368,6 +377,18 @@ plot_DRTResults <- function(
                      "\n",
                      sep = ""),
                ""),
+        ifelse("serel" %in% summary == TRUE,
+               paste("se = ",
+                     round(calc_Statistics(values[[i]])$unweighted$se.rel, 2),
+                     " %\n",
+                     sep = ""),
+               ""),
+        ifelse("seabs" %in% summary == TRUE,
+               paste("se = ",
+                     round(calc_Statistics(values[[i]])$unweighted$se.abs, 2),
+                     "\n",
+                     sep = ""),
+               ""),
         sep = ""), stops, sep = "")
 
     }
@@ -413,7 +434,20 @@ plot_DRTResults <- function(
                      " | ",
                      sep = ""),
                ""),
+        ifelse("serel" %in% summary == TRUE,
+               paste("se = ",
+                     round(calc_Statistics(values[[i]])$unweighted$se.rel, 2),
+                     " % | ",
+                     sep = ""),
+               ""),
+        ifelse("seabs" %in% summary == TRUE,
+               paste("se = ",
+                     round(calc_Statistics(values[[i]])$unweighted$se.abs, 2),
+                     " | ",
+                     sep = ""),
+               ""),
         sep = "")
+
     }
   }
 
@@ -502,6 +536,8 @@ plot_DRTResults <- function(
   ## setup plot area
   if(par.local){
 
+    if (shift.lines <= 0)
+      shift.lines <- 1
     par.default <- par()[c("mfrow", "cex", "oma")]
     par(mfrow = c(1, 1), cex = cex, oma = c(0, 1, shift.lines - 1, 1))
   }
@@ -527,26 +563,40 @@ plot_DRTResults <- function(
             line = shift.lines + 2)
 
       ## add additional lines
-      abline(h = 1)
+      if (!is.null(given.dose)) {
+        abline(h = 1)
 
-      if(error.range > 0){
-        ## error range lines
-        abline(h = 1 * (1 + error.range / 100), lty = 2)
-        abline(h = 1 * (1 - error.range / 100), lty = 2)
+        if (error.range > 0) {
+          ## error range lines
+          abline(h = 1 * (1 + error.range / 100), lty = 2)
+          abline(h = 1 * (1 - error.range / 100), lty = 2)
+
+          ## error range labels
+          text(
+            par()$usr[2],
+            (1 + error.range / 100) + 0.02,
+            paste("+", error.range , " %", sep = ""),
+            pos = 2,
+            cex = 0.8
+          )
+          text(
+            par()$usr[2],
+            (1 - error.range / 100) - 0.02,
+            paste("-", error.range , "%", sep = ""),
+            pos = 2,
+            cex = 0.8
+          )
+        }
 
-        ## error range labels
-        text(par()$usr[2], (1 + error.range / 100) + 0.02,
-             paste("+", error.range ," %", sep = ""), pos = 2, cex = 0.8)
-        text(par()$usr[2], (1 - error.range / 100) - 0.02,
-             paste("-", error.range ,"%", sep = ""), pos = 2, cex = 0.8)
       }
 
       ## add data and error bars
       for(i in 1:length(values)) {
+
         points(x = c(1:nrow(values[[i]])),
                y = values[[i]][,1],
-               pch = pch[i],
-               col = col[i],
+               pch = if(nrow(values[[i]]) == length(pch)){ pch } else { pch[i] },
+               col = if(nrow(values[[i]]) == length(col)){ col } else { col[i] },
                cex = 1.2 * cex)
 
         arrows(c(1:nrow(values[[i]])),
@@ -556,7 +606,7 @@ plot_DRTResults <- function(
                angle = 90,
                length = 0.075,
                code = 3,
-               col = col[i])
+               col = if(nrow(values[[i]]) == length(col)){ col } else { col[i] })
 
         ## add summary content
         if(summary.pos[1] != "sub") {
@@ -600,18 +650,30 @@ plot_DRTResults <- function(
             line = shift.lines + 2)
 
       ## add additional lines
-      abline(h = 1)
+      if (!is.null(given.dose)) {
+        abline(h = 1)
 
-      if(error.range > 0){
-        ## error range lines
-        abline(h = 1 * (1 + error.range / 100), lty = 2)
-        abline(h = 1 * (1 - error.range / 100), lty = 2)
+        if (error.range > 0) {
+          ## error range lines
+          abline(h = 1 * (1 + error.range / 100), lty = 2)
+          abline(h = 1 * (1 - error.range / 100), lty = 2)
 
-        ## error range labels
-        text(par()$usr[2], (1 + error.range / 100) + 0.02,
-             paste("+", error.range ," %", sep = ""), pos = 2, cex = 0.8)
-        text(par()$usr[2], (1 - error.range / 100) - 0.02,
-             paste("-", error.range ,"%", sep = ""), pos = 2, cex = 0.8)
+          ## error range labels
+          text(
+            par()$usr[2],
+            (1 + error.range / 100) + 0.02,
+            paste("+", error.range , " %", sep = ""),
+            pos = 2,
+            cex = 0.8
+          )
+          text(
+            par()$usr[2],
+            (1 - error.range / 100) - 0.02,
+            paste("-", error.range , "%", sep = ""),
+            pos = 2,
+            cex = 0.8
+          )
+        }
       }
 
       ## plot values
