@@ -69,13 +69,14 @@
 #' internal coercing is done using the function \code{\link{Risoe.BINfileData2RLum.Analysis}}
 #'
 #'
-#' @note The function works for BIN/BINX-format versions 03, 04, 06 and 07. The
-#' version number depends on the used Sequence Editor.\cr\cr \bold{Potential
-#' other BIN/BINX-format versions are currently not supported. The
-#' implementation of version 07 support could not been tested properly so far.}.
+#' @note The function works for BIN/BINX-format versions 03, 04, 06, 07 and 08. The
+#' version number depends on the used Sequence Editor.\cr\cr
+#'
+#' \bold{ROI data sets introduced with BIN-file version 8 are not supported and skipped durint
+#' import.}
 #'
 #'
-#' @section Function version: 0.14.0
+#' @section Function version: 0.15.0
 #'
 #'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
@@ -87,8 +88,9 @@
 #' \code{\link[utils]{txtProgressBar}}, \code{\link{list.files}}
 #'
 #'
-#' @references Duller, G., 2007. Analyst.
-#' \url{http://www.nutech.dtu.dk/english/~/media/Andre_Universitetsenheder/Nutech/Produkter\%20og\%20services/Dosimetri/radiation_measurement_instruments/tl_osl_reader/Manuals/analyst_manual_v3_22b.ashx}
+#' @references
+#' DTU Nutech, 2016. The Squence Editor, Users Manual, February, 2016.
+#' \url{http://www.nutech.dtu.dk/english/Products-and-Services/Dosimetry/Radiation-Measurement-Instruments/TL_OSL_reader/Manuals}
 #'
 #'
 #' @keywords IO
@@ -279,7 +281,7 @@ read_BIN2R <- function(
   # Config ------------------------------------------------------------------
 
   ##set supported BIN format version
-  VERSION.supported <- as.raw(c(03, 04, 06, 07))
+  VERSION.supported <- as.raw(c(03, 04, 06, 07, 08))
 
 
   # Short file parsing to get number of records -------------------------------------------------
@@ -338,10 +340,11 @@ read_BIN2R <- function(
     #empty byte position
     EMPTY<-readBin(con, what="raw", 1, size=1, endian="litte")
 
-    if(temp.VERSION==06 | temp.VERSION==07){
+    if(temp.VERSION == 06 | temp.VERSION == 07 | temp.VERSION == 08){
 
       ##GET record LENGTH
       temp.LENGTH  <- readBin(con, what="int", 1, size=4, endian="little")
+
       STEPPING <- readBin(con, what="raw", temp.LENGTH-6, size=1, endian="litte")
 
     }else{
@@ -453,12 +456,21 @@ read_BIN2R <- function(
   temp.GRAINNUMBER <- NA
   temp.LIGHTPOWER <- NA
   temp.LPOWER <- NA
+  temp.RECTYPE <- 0
+  temp.MARKPOS_X1 <- NA
+  temp.MARKPOS_Y1 <- NA
+  temp.MARKPOS_X2 <- NA
+  temp.MARKPOS_Y2 <- NA
+  temp.MARKPOS_X3 <- NA
+  temp.MARKPOS_Y3 <- NA
+  temp.EXTR_START <- NA
+  temp.EXTR_END <- NA
 
   ##SET length of entire record
   n.length <- n.records
 
   ##initialise data.frame
-  results.METADATA <- data.table(
+  results.METADATA <- data.table::data.table(
 
     ID = integer(length = n.length),
     SEL = logical(length = n.length),
@@ -466,6 +478,7 @@ read_BIN2R <- function(
     LENGTH = integer(length = n.length),
     PREVIOUS = integer(length = n.length),
     NPOINTS = integer(length = n.length),
+    RECTYPE = integer(length = n.length),
 
     RUN = integer(length = n.length),
     SET = integer(length = n.length),
@@ -535,6 +548,14 @@ read_BIN2R <- function(
     LOWERFILTER_ID = integer(length = n.length),
     UPPERFILTER_ID = integer(length = n.length),
     ENOISEFACTOR = numeric(length = n.length),
+    MARKPOS_X1 = numeric(length = n.length),
+    MARKPOS_Y1 = numeric(length = n.length),
+    MARKPOS_X2 = numeric(length = n.length),
+    MARKPOS_Y2 = numeric(length = n.length),
+    MARKPOS_X3 = numeric(length = n.length),
+    MARKPOS_Y3 = numeric(length = n.length),
+    EXTR_START = numeric(length = n.length),
+    EXTR_END = numeric(length = n.length),
 
     SEQUENCE = character(length = n.length)
 
@@ -572,7 +593,7 @@ read_BIN2R <- function(
   ##read data up to the end of con
 
   ##set ID
-  temp.ID<-0
+  temp.ID <- 0
 
 
   # LOOP --------------------------------------------------------------------
@@ -617,7 +638,7 @@ read_BIN2R <- function(
 
     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     # BINX FORMAT SUPPORT -----------------------------------------------------
-    if(temp.VERSION==06 | temp.VERSION==07){
+    if(temp.VERSION == 06 | temp.VERSION == 07 | temp.VERSION == 08){
 
       ##(1) Header size and strucutre
       ##LENGTH, PREVIOUS, NPOINTS, LTYPE
@@ -627,6 +648,20 @@ read_BIN2R <- function(
       temp.PREVIOUS <- temp[2]
       temp.NPOINTS <- temp[3]
 
+      ##for temp.VERSION == 08
+      ##RECTYPE
+      if(temp.VERSION == 08){
+        temp.RECTYPE <- readBin(con, what="int", 1, size=1, endian="little", signed = FALSE)
+        if(temp.RECTYPE == 128){
+          STEPPING<-readBin(con, what="raw", temp.LENGTH)
+
+          warning("[read_BIN2R()] ROI definition in data set detected, but currently not supported, skipped!", call. = FALSE)
+
+          next()
+        }
+      }
+
+
       ##(2) Sample characteristics
       ##RUN, SET, POSITION, GRAINNUMBER, CURVENO, XCOORD, YCOORD
       temp <- readBin(con, what="int", 7, size=2, endian="little")
@@ -864,8 +899,35 @@ read_BIN2R <- function(
         ##ENOISEFACTOR
         temp.ENOISEFACTOR <- readBin(con, what="double", 1, size=4, endian="little")
 
-        ##RESERVED
-        temp.RESERVED2<-readBin(con, what="raw", 15, size=1, endian="little")
+        ##CHECK FOR VERSION 08
+        if(temp.VERSION == 07){
+
+           ##RESERVED for version 07
+          temp.RESERVED2<-readBin(con, what="raw", 15, size=1, endian="little")
+
+        }else{
+
+          ##MARKER_POSITION
+          temp <- readBin(con, what="double", 6, size=4, endian="little")
+
+            temp.MARPOS_X1 <- temp[1]
+            temp.MARPOS_Y1 <- temp[2]
+            temp.MARPOS_X2 <- temp[3]
+            temp.MARPOS_Y2 <- temp[4]
+            temp.MARPOS_X3 <- temp[5]
+            temp.MARPOS_Y3 <- temp[6]
+
+
+          ###EXTR_START, EXTR_END
+          temp <- readBin(con, what="double", 2, size=4, endian="little")
+
+            temp.EXTR_START <- temp[1]
+            temp.EXTR_END <- temp[2]
+
+          temp.RESERVED2<-readBin(con, what="raw", 42, size=1, endian="little")
+
+        }
+
 
       }
 
@@ -916,6 +978,7 @@ read_BIN2R <- function(
       ##TIME
       TIME_SIZE<-readBin(con, what="int", 1, size=1, endian="little")
 
+
       ##time size corrections for wrong time formats; set n to 6 for all values
       ##accoording the handbook of Geoff Duller, 2007
       TIME_SIZE<-6
@@ -1117,6 +1180,7 @@ read_BIN2R <- function(
       LENGTH = temp.LENGTH,
       PREVIOUS = temp.PREVIOUS,
       NPOINTS = temp.NPOINTS,
+      RECTYPE = temp.RECTYPE,
       RUN = temp.RUN,
       SET = temp.SET,
       POSITION = temp.POSITION,
@@ -1181,9 +1245,14 @@ read_BIN2R <- function(
       LOWERFILTER_ID = temp.LOWERFILTER_ID,
       UPPERFILTER_ID = temp.UPPERFILTER_ID,
       ENOISEFACTOR = temp.ENOISEFACTOR,
+      MARKPOS_X1 = temp.MARKPOS_X1,
+      MARKPOS_Y1 = temp.MARKPOS_Y1,
+      MARKPOS_X2 = temp.MARKPOS_X2,
+      MARKPOS_Y2 = temp.MARKPOS_Y2,
+      MARKPOS_X3 = temp.MARKPOS_X3,
+      MARKPOS_Y3 = temp.MARKPOS_Y3,
       SEQUENCE = temp.SEQUENCE
 
-
     )]
 
     results.DATA[[temp.ID]] <- temp.DPOINTS
