@@ -9,31 +9,35 @@
 #'
 #' @param object \code{\linkS4class{RLum}} (\bold{required}): S4 object of
 #' class \code{RLum}
+#'
+#' @param \dots further arguments that one might want to pass to the specific
+#' structure method
+#'
 #' @return Returns a \code{data.frame} with structure of the object.
-#' @section Function version: 0.1.0
+#'
+#' @section Function version: 0.2.0
+#'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
 #' (France)
+#'
 #' @seealso
 #' \code{\linkS4class{RLum.Data.Curve}},
 #' \code{\linkS4class{RLum.Data.Image}},
 #' \code{\linkS4class{RLum.Data.Spectrum}},
 #' \code{\linkS4class{RLum.Analysis}},
 #' \code{\linkS4class{RLum.Results}}
+#'
 #' @keywords utilities
-#' @aliases get_structure.RLum.Analysis
+#'
+#' @examples
+#'
+#' ##load example data
+#' data(ExampleData.XSYG, envir = environment())
+#'
+#' ##show structure
+#' structure_RLum(OSL.SARMeasurement$Sequence.Object)
 #'
 #' @export
-setGeneric("structure_RLum", function(object) {
+setGeneric("structure_RLum", function(object, ...) {
   standardGeneric("structure_RLum")
 })
-
-## ---- DEPRECATED GENERICS
-# .Deprecated in package version 0.5.0
-# .Defunct in 0.5.X
-# Removed in 0.6.0
-
-#' @noRd
-get_structure.RLum.Analysis <- function(...) {
-  .Deprecated("get_structure.RLum.Analysis")
-  structure_RLum(...)
-}
